﻿//In this script we have dragger object which has spring joint component attached.
//When we move mouse or finger (for touch device) on screen and "forTouchScreen" variable is set to true(from inspector window)
//We are positioning dragger object to that position. If we click/tap on 2D object tagged as tack, connect to it. 
//So now when you move cursor/finger, dragger object follows it and unity's physics does everything else to make object follow

using UnityEngine;
using System.Collections;

public class Drag : MonoBehaviour {
	public bool forTouchScreen = false;	//determines what input to use (mouse or finger)
	public GameObject dragger;			//dragger object
	public LayerMask layerMask;			//determines which layer objects will be able to drag
    
	private Rigidbody2D connectedRB;	//saves object on which dragger object is connected
	private bool dragging = false;		//is true when we are moving dragger object
	private Transform hitObject;		//object which was last hit by raycast
	private bool movingTransform;		//is true when we are moving object which doesn't have rigidbody2D component

    private Vector3 lastPos;
    private musicTools curMusic;
    
	void Start()
	{
		//create dragger object
		if(!dragger)
		{
			dragger = new GameObject("dragger");
			dragger.AddComponent<SpringJoint2D>();
		}
	    lastPos = Vector3.zero;
        StoneManager.Instance.ResetStrone();
        SceneManager.Instance.Reset();
	    //AudioManager.Instance.PlayBackage();

	}
	
	void Update ()
	{
        //detect input (touch or mouse button 1)

        if (SceneManager.Instance.IsLogo || SceneManager.Instance.checkWining)
            return;
        if (forTouchScreen ? Input.touchCount > 0 : Input.GetMouseButton(0))
        {

            SceneManager.Instance.IsDraging = true;
			Vector3 pos;
			//if forTouchScreen variable is true (set from inspector window) use touches, else use mouse for dragging
			if(forTouchScreen)
				pos = GetComponent<Camera>().ScreenToWorldPoint(Input.GetTouch(0).position);//get position, where touch is detected
			else
				pos = GetComponent<Camera>().ScreenToWorldPoint(Input.mousePosition); //get position, where mouse cursor is
			pos.z = -1;

			//make dragger object's position same as input position
			dragger.transform.position = pos;
			
			//cast ray
			RaycastHit2D  hit;
			hit = Physics2D.Raycast(pos, Vector2.zero, Mathf.Infinity, layerMask);
            if (hit.transform && !hitObject)
            {
                if (!hitObject)
                    hitObject = hit.transform;

                if (hit.collider != null)
                    connectedRB = hit.collider.GetComponent<Rigidbody2D>();

                if (!dragging) //第一次触发
                {
                    if (hitObject && hit.transform)
                    {
                        curMusic = hit.transform.GetComponent<musicTools>();
                        if (curMusic)
                        {
                            AudioManager.Instance.Play(curMusic.music, false);
                        }
                    }
                }

                if (!dragging && hitObject && hitObject.gameObject.name == "fuwen3")
                {
                    SceneManager.Instance.IsDraging = false;
                    hitObject.gameObject.GetComponent<BoxCollider2D>().enabled = false;
                    SceneManager.Instance.ReloadNextScene();
                }
                else if (hitObject && hitObject.gameObject.name == "left")
                {
                    SceneManager.Instance.IsDraging = false;
                    hitObject.gameObject.GetComponent<BoxCollider2D>().enabled = false;
                    SceneManager.Instance.ReloadPreScene();

                }
                else if (hitObject && hitObject.gameObject.name == "right")
                {
                    SceneManager.Instance.IsDraging = false;
                    hitObject.gameObject.GetComponent<BoxCollider2D>().enabled = false;
                    SceneManager.Instance.ReloadNextScene1();

                }
                else if (hitObject && hitObject.gameObject.name == "reset")
                {

                    SceneManager.Instance.IsDraging = false;
                    hitObject.gameObject.GetComponent<BoxCollider2D>().enabled = false;
                    SceneManager.Instance.ReloadScene();

                }
                else
                {
                    if (connectedRB != null && hitObject)
                    {
                        connectedRB.isKinematic = true;
                        hitObject.position = pos;
                    }
                }

                dragging = true;
            }
            else
            {
                if (connectedRB != null && hitObject)
                {
                    connectedRB.isKinematic = true;
                    hitObject.position = pos;
                }
            }
           
            /*if (hit.transform != null)
		    {
                SpriteRenderer sr = hit.transform.GetComponent<SpriteRenderer>();
                if (sr != null)
                {
                    sr.color = Color.white;
                }
            }*/

        }
        else if (Input.GetMouseButton(1))
        {
            Vector3 pos;
            if (forTouchScreen)
                pos = GetComponent<Camera>().ScreenToWorldPoint(Input.GetTouch(0).position);//get position, where touch is detected
            else
                pos = GetComponent<Camera>().ScreenToWorldPoint(Input.mousePosition); //get position, where mouse cursor is
            pos.z = -1;
            
            dragger.transform.position = pos;
            
            RaycastHit2D hit;
            hit = Physics2D.Raycast(pos, Vector2.zero, Mathf.Infinity, layerMask);

            if (!hitObject)
                hitObject = hit.transform;
            
            if (hit.collider != null)
                connectedRB = hit.collider.GetComponent<Rigidbody2D>();
            if (connectedRB != null && hitObject )
            {
                Vector3 ver = Vector3.zero;
                float len = lastPos.y - pos.y;
                ver.z = len*100;
                hitObject.localEulerAngles = ver;
                //lastPos = hit.transform.localPosition;
            }
            if (connectedRB)
                connectedRB.isKinematic = true;

            if (!dragging) //第一次触发
            {
                if (hit.transform)
                {
                    lastPos = hit.transform.position;
                }
            }

            dragging = true;
        }
		else
        {
            if (dragging && curMusic)
            {
                AudioManager.Instance.Play(curMusic.music, false);
                //StoneManager.Instance.CloseKinematic();
            }
            SceneManager.Instance.IsDraging = false;
            if (connectedRB)
				connectedRB.isKinematic = false;
			dragging = false;
			movingTransform = false;
			hitObject = null;
		}
	}
}
